- Annotations
-
- @Deprecated('The 0.5.x compatible API will be removed in a future release. Use the native API from package:tray_manager/tray_manager.dart.')
Constructors
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
onTrayIconMouseDown(
) → void -
onTrayIconMouseUp(
) → void -
onTrayIconRightMouseDown(
) → void -
onTrayIconRightMouseUp(
) → void -
onTrayMenuItemClick(
) → void -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited