popUpContextMenu method

Future<void> popUpContextMenu({
  1. @Deprecated('This parameter is only supported by the old platform implementation.') bool bringAppToFront = false,
})

Implementation

Future<void> popUpContextMenu({
  @Deprecated(
    'This parameter is only supported by the old platform implementation.',
  )
  bool bringAppToFront = false,
}) async {
  _ensureTrayIcon.openContextMenu();
}