TrayManager class
The pre-nativeapi TrayManager on top of a single nativeapi.TrayIcon,
for code that has not moved to the native API yet.
- Annotations
-
- @Deprecated('The 0.5.x compatible API will be removed in a future release. Use the native API from package:tray_manager/tray_manager.dart.')
Properties
- contextMenu → Menu?
-
no setter
- hashCode → int
-
The hash code for this object.
no setterinherited
- hasListeners → bool
-
no setter
- isSupported → bool
-
no setter
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- trayIcon → TrayIcon?
-
no setter
Methods
-
addListener(
TrayListener listener) → void -
destroy(
) → Future< void> -
getBounds(
) → Future< Rect?> - The bounds of this tray icon, in logical pixels as before; null where the system does not tell (Linux).
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
popUpContextMenu(
{bool bringAppToFront = false}) → Future< void> -
removeListener(
TrayListener listener) → void -
setContextMenu(
) → Future< void> -
setIcon(
String iconPath, {bool isTemplate = false, TrayIconPosition iconPosition = TrayIconPosition.left, int iconSize = 18}) → Future< void> -
setIconPosition(
TrayIconPosition trayIconPosition) → Future< void> - Sets the icon position of the tray icon.
-
setTitle(
String title) → Future< void> -
setToolTip(
String toolTip) → Future< void> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Properties
- instance → TrayManager
-
The shared instance of TrayManager.
final